@@ -520,7 +520,7 @@ def write(t, c, size=16, style=None, family=None):
 
 
 @check_pen
-def tetris_CZ(t, x=None, y=None, size=50):
+def tetris_cz(t, x=None, y=None, size=50):
     if x is None:
         x = t.xcor()
     if y is None:
@@ -537,7 +537,7 @@ def tetris_CZ(t, x=None, y=None, size=50):
 
 
 @check_pen
-def tetris_RZ(t, x=None, y=None, size=50):
+def tetris_rz(t, x=None, y=None, size=50):
     if x is None:
         x = t.xcor()
     if y is None:
@@ -554,7 +554,7 @@ def tetris_RZ(t, x=None, y=None, size=50):
 
 
 @check_pen
-def tetris_OR(t, x=None, y=None, size=50):
+def tetris_or(t, x=None, y=None, size=50):
     if x is None:
         x = t.xcor()
     if y is None:
@@ -571,7 +571,7 @@ def tetris_OR(t, x=None, y=None, size=50):
 
 
 @check_pen
-def tetris_BR(t, x=None, y=None, size=50):
+def tetris_br(t, x=None, y=None, size=50):
     if x is None:
         x = t.xcor()
     if y is None:
@@ -588,7 +588,7 @@ def tetris_BR(t, x=None, y=None, size=50):
 
 
 @check_pen
-def tetris_H(t, x=None, y=None, size=50):
+def tetris_h(t, x=None, y=None, size=50):
     if x is None:
         x = t.xcor()
     if y is None:
@@ -605,7 +605,7 @@ def tetris_H(t, x=None, y=None, size=50):
 
 
 @check_pen
-def tetris_T(t, x=None, y=None, size=50):
+def tetris_t(t, x=None, y=None, size=50):
     if x is None:
         x = t.xcor()
     if y is None:
@@ -622,7 +622,7 @@ def tetris_T(t, x=None, y=None, size=50):
 
 
 @check_pen
-def tetris_S(t, x=None, y=None, size=50):
+def tetris_s(t, x=None, y=None, size=50):
     if x is None:
         x = t.xcor()
     if y is None:
